@@ -652,6 +652,18 @@ screenshot_application_handle_local_options (GApplication *app,
       exit (EXIT_SUCCESS);
     }
 
+  /* Start headless instances in non-unique mode */
+  if (!g_variant_dict_contains (options, "interactive"))
+    {
+      GApplicationFlags old_flags;
+
+      old_flags = g_application_get_flags (app);
+      if ((old_flags & G_APPLICATION_IS_SERVICE) == 0)
+        {
+          g_application_set_flags (app, old_flags | G_APPLICATION_NON_UNIQUE);
+        }
+    }
+
   return -1;
 }
 
@@ -678,26 +690,24 @@ screenshot_application_command_line (GApplication            *app,
   g_variant_dict_lookup (options, "clipboard", "b", &clipboard_arg);
   g_variant_dict_lookup (options, "window", "b", &window_arg);
   g_variant_dict_lookup (options, "area", "b", &area_arg);
-  g_variant_dict_lookup (options, "clipboard", "b", &clipboard_arg);
   g_variant_dict_lookup (options, "include-border", "b", &include_border_arg);
   g_variant_dict_lookup (options, "remove-border", "b", &disable_border_arg);
   g_variant_dict_lookup (options, "include-pointer", "b", &include_pointer_arg);
   g_variant_dict_lookup (options, "interactive", "b", &interactive_arg);
   g_variant_dict_lookup (options, "border-effect", "&s", &border_effect_arg);
-  g_variant_dict_lookup (options, "delay", "u", &delay_arg);
-  g_variant_dict_lookup (options, "file", "&s", &file_arg);
-
-  res = screenshot_load_config (clipboard_arg,
-                                window_arg,
-                                area_arg,
-                                include_border_arg,
-                                disable_border_arg,
-                                include_pointer_arg,
-                                border_effect_arg,
-                                delay_arg,
-                                interactive_arg,
-                                file_arg);
+  g_variant_dict_lookup (options, "delay", "i", &delay_arg);
+  g_variant_dict_lookup (options, "file", "^&ay", &file_arg);
 
+  res = screenshot_config_parse_command_line (clipboard_arg,
+                                              window_arg,
+                                              area_arg,
+                                              include_border_arg,
+                                              disable_border_arg,
+                                              include_pointer_arg,
+                                              border_effect_arg,
+                                              delay_arg,
+                                              interactive_arg,
+                                              file_arg);
   if (!res)
     {
       exit_status = EXIT_FAILURE;
@@ -706,7 +716,7 @@ screenshot_application_command_line (GApplication            *app,
 
   /* interactive mode: trigger the dialog and wait for the response */
   if (screenshot_config->interactive)
-    screenshot_show_interactive_dialog (self);
+    g_application_activate (app);
   else
     screenshot_start (self);
 
@@ -772,21 +782,18 @@ static GActionEntry action_entries[] = {
 static void
 screenshot_application_startup (GApplication *app)
 {
+  GMenuModel *menu;
+  GtkBuilder *builder;
   ScreenshotApplication *self = SCREENSHOT_APPLICATION (app);
 
   G_APPLICATION_CLASS (screenshot_application_parent_class)->startup (app);
 
+  screenshot_load_config ();
+
   gtk_window_set_default_icon_name (SCREENSHOOTER_ICON);
 
   g_action_map_add_action_entries (G_ACTION_MAP (self), action_entries,
                                    G_N_ELEMENTS (action_entries), self);
-}
-
-static void
-screenshot_application_activate (GApplication *app)
-{
-  GtkBuilder *builder;
-  GMenuModel *menu;
 
   builder = gtk_builder_new ();
   gtk_builder_add_from_resource (builder, "/org/gnome/screenshot/screenshot-app-menu.ui", NULL);
@@ -797,6 +804,22 @@ screenshot_application_activate (GApplication *app)
   g_object_unref (menu);
 }
 
+static void
+screenshot_application_activate (GApplication *app)
+{
+  GtkWindow *window;
+
+  window = gtk_application_get_active_window (GTK_APPLICATION (app));
+  if (window != NULL)
+    {
+      gtk_window_present (GTK_WINDOW (window));
+      return;
+    }
+
+  screenshot_config->interactive = TRUE;
+  screenshot_show_interactive_dialog (SCREENSHOT_APPLICATION (app));
+}
+
 static void
 screenshot_application_finalize (GObject *object)
 {
